#ifndef MAINWINDOWUI_H
#define MAINWINDOWUI_H

#include <QWidget>
#include <qipdialogbox.h>
#include <QLabel>
#include <QPushButton>
#include <QGridLayout>
#include <QVBoxLayout>
#include <QGroupBox>
#include <QSpinBox>
#include <QTextEdit>
#include <QTabWidget>

#include <wfdisplay.h>
#include <pagespectra.h>
#include <asmpage.h>
#include <parameterdump.h>

#include "tmstatistics.h"
#include "hkdisplay.h"
#include "recordpage.h"
#include "storehk.h"

class MainWindowUI : public QWidget
{
    Q_OBJECT
public:
    explicit MainWindowUI(QWidget *parent = 0);

    void setTCTMServerAddressIP(QString address);
    QString getTMEchoServerAddress();
    int getTMPort();
    int getTCPort();
    void displayOnConsole(QString message);

    QTabWidget *spwTabWidget;
    QWidget* spwTabWidgetPage0;
    QWidget* spwTabWidgetPage1;
    QWidget* spwTabWidgetPage2;
    QWidget* spwTabWidgetPage3;

    TMStatistics* tmStatistics;

    WFDisplay* wfDisplay;
    WFPage* wfPage_CWF_F1;
    WFPage* wfPage_CWF_F2;
    WFPage* wfPage_CWF_F3;
    ASMPage* asmPage_F0;
    ASMPage* asmPage_F1;
    ASMPage* asmPage_F2;
    HKDisplay* hkDisplay;
    RecordPage* recordPage;

    StoreHK *storeHK;

    QWidget* widget_spectrogram;

    ParameterDump* parameterDump;

    QPushButton *button_openServerTCTM;
    QPushButton *button_testServerTCTM;
    QPushButton *button_openSocketEchoServer;
    QPushButton *button_TCAcknowledgement;
    QPushButton *button_TCRejection;
    QPushButton *button_GSEHK;
    QPushButton *button_clearConsole;
    QPushButton *button_resetStatistics;

    QIPDialogBox *serverTMEchoDialogBox;

    QSpinBox *spinbox_serverTMEchoPort;
    
signals:
    
public slots:
    void clearConsole();
    void totalOfBytesHasChanged(unsigned int nbBytes);
    void totalOfPacketsHasChanged(unsigned int nbPackets);

private:
    QLabel *label_serverTMEcho;
    QLabel *label_serverTMEchoPort;
    QLabel *label_TMServerPort;
    QLabel *label_TCServerPort;
    QLabel *label_currentTCTMServer;
    QLabel *label_currentTCTMServerIP;
    QLabel *label_totalOfBytes;
    QLabel *label_totalOfPackets;

    QTextEdit *console;

    QSpinBox *spinbox_TMServerPort;
    QSpinBox *spinbox_TCServerPort;

    QGroupBox *groupbox_TMEcho;
    QGroupBox *groupbox_ports;
    QGroupBox *groupbox_TMToForeignGSETester;

    QVBoxLayout *layout_TMEcho;
    QVBoxLayout *layout_TMToForeignGSETester;
    QVBoxLayout *layout_overallLayout;

    QGridLayout *mainLayout;
    QGridLayout *layout_ports;
    
};

#endif // MAINWINDOWUI_H
